@@ -3,9 +3,11 @@ import typing
 from abc import ABC
 
 import pydantic
-from pydantic import validator, root_validator
+from pydantic import root_validator, validator
+
 from qhub.utils import namestr_regex
-from .version import rounded_ver_parse, __version__
+
+from .version import __version__, rounded_ver_parse
 
 
 class CertificateEnum(str, enum.Enum):
@@ -74,6 +76,21 @@ class HelmExtension(Base):
     overrides: typing.Optional[typing.Dict]
 
 
+# ============== Argo-Workflows =========
+
+
+class ArgoWorkflows(Base):
+    enabled: bool
+    overrides: typing.Optional[typing.Dict]
+
+
+# ============== kbatch =============
+
+
+class KBatch(Base):
+    enabled: bool
+
+
 # ============== Monitoring =============
 
 
@@ -478,6 +495,8 @@ class Main(Base):
     theme: Theme
     profiles: Profiles
     environments: typing.Dict[str, CondaEnvironment]
+    argo_workflows: typing.Optional[ArgoWorkflows]
+    kbatch: typing.Optional[KBatch]
     monitoring: typing.Optional[Monitoring]
     clearml: typing.Optional[ClearML]
     tf_extensions: typing.Optional[typing.List[QHubExtension]]
